# == Schema Information
# Schema version: 20090612184651
#
# Table name: pitches
#
#  id          :integer         not null, primary key
#  name        :string(255)
#  floor       :string(255)
#  location    :string(255)
#  description :text
#  latitude    :string(255)
#  longitude   :string(255)
#  created_at  :datetime
#  updated_at  :datetime
#  creator_id  :integer
#

class Pitch < ActiveRecord::Base

  hobo_model # Don't put anything above this

  fields do
    name :string
    location :string
    floor enum_string(:dirt, :cement, :grass, :synthetic, :tar, :wood)
    description :html
    contacts :html
    latitude :string
    longitude :string
    timestamps
  end

  never_show :latitude, :longitude

  has_many :playable_sports, :dependent => :destroy
  has_many :sports, :through => :playable_sports, :accessible => true
  belongs_to :creator, :class_name => "User", :foreign_key => "creator_id", :creator => true
  has_many :comments, :dependent => :destroy

  validates_presence_of :name
  validates_uniqueness_of :name

  def owner
    creator
  end

  def before_validation_on_create
    placemarks = Geocoding.get(self.location)

    unless placemarks.empty?
      self.latitude = placemarks.first.latitude
      self.longitude = placemarks.first.longitude
    else
      self.latitude = ""
      self.longitude = ""
    end
  end

  def validate_on_create
    if self.latitude.blank? or self.longitude.blank?
      self.errors.add("location", "is unknown")
    end
  end

  # --- Permissions --- #

  def create_permitted?
    creator_is? acting_user
  end

  def update_permitted?
    acting_user.signed_up? && !creator_changed?
  end

  def destroy_permitted?
    acting_user.administrator?
  end

  def view_permitted?(field)
    true
  end
end
